@@ -33,6 +33,12 @@ sub new {
     return $self;
 }
 
+sub File::lockf::lock_obj::fh {
+    my ($self) = @_;
+    
+    return $self->{fh};
+}
+
 sub File::lockf::lock_obj::lock {
     my ($self, $size) = @_;
     $size = 0 unless $size;
@@ -146,6 +152,10 @@ This function returns a new lock object bound to the given file
 handle. Note that you need to pass a reference to the file handle
 to the constructor, not the file handle itself.
 
+=item $fh = $lock->fh()
+
+This method returns the file handle associated with the lock object.
+
 =item $status = $lock->lock(size = 0)
 
 This method calls File::lockf::lock on the bound file handle.
